#
# spec file for package kwayland
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define _tar_path 5.45
# Full KF5 version (e.g. 5.33.0)
%{!?_kf5_version: %global _kf5_version %{version}}
# Last major and minor KF5 version (e.g. 5.33)
%{!?_kf5_bugfix_version: %global _kf5_bugfix_version %(echo %{_kf5_version} | awk -F. '{print $1"."$2}')}
Name:           kwayland
Version:        5.45.0
Release:        lp150.1.1
Summary:        KDE Wayland library
License:        LGPL-2.1-or-later
Group:          Development/Libraries/KDE
Url:            http://www.kde.org
Source:         http://download.kde.org/stable/frameworks/%{_tar_path}/%{name}-%{version}.tar.xz
Source1:        baselibs.conf
BuildRequires:  cmake >= 3.0
BuildRequires:  extra-cmake-modules >= %{_kf5_bugfix_version}
BuildRequires:  fdupes
BuildRequires:  kf5-filesystem
BuildRequires:  libQt5Gui-private-headers-devel >= 5.6.0
BuildRequires:  cmake(Qt5Concurrent) >= 5.6.0
BuildRequires:  cmake(Qt5Gui) >= 5.6.0
BuildRequires:  cmake(Qt5Test) >= 5.6.0
BuildRequires:  pkgconfig(egl)
%if 0%{?suse_version} == 1315 && ! 0%{?is_opensuse}
# We have a patched wayland 1.2.1 version in SLE12 with the required features from 1.7.0
BuildRequires:  pkgconfig(wayland-client) >= 1.2.1
BuildRequires:  pkgconfig(wayland-server) >= 1.2.1
%else
BuildRequires:  pkgconfig(wayland-client) >= 1.7.0
BuildRequires:  pkgconfig(wayland-server) >= 1.7.0
%endif
Provides:       libKF5WaylandClient5 = %{version}
Obsoletes:      libKF5WaylandClient5 <= %{version}
Provides:       libKF5WaylandServer5 = %{version}
Obsoletes:      libKF5WaylandServer5 <= %{version}
%requires_eq libQt5Gui5
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
KWayland provides a Qt-style Client and Server library wrapper for the Wayland libraries.

%package devel
Summary:        KDE Wayland library: Build Environment
Group:          Development/Libraries/KDE
Requires:       %{name} = %{version}
Requires:       extra-cmake-modules >= 1.2.0
Requires:       cmake(Qt5Gui) >= 5.6.0

%description devel
KWayland provides a Qt-style Client and Server library wrapper for the Wayland libraries.

%prep
%setup -q

%build
  %cmake_kf5 -d build
  %make_jobs

%install
  %kf5_makeinstall -C build

%post   -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc COPYING*
%config %{_kf5_configdir}/org_kde_kwayland.categories
%{_kf5_libdir}/libKF5WaylandClient.so.*
%{_kf5_libdir}/libKF5WaylandServer.so.*

%files devel
%defattr(-,root,root)
%{_kf5_libdir}/libKF5WaylandClient.so
%{_kf5_libdir}/libKF5WaylandServer.so
%{_kf5_libdir}/libexec/org-kde-kf5-kwayland-testserver
%{_kf5_libdir}/cmake/KF5Wayland/
%{_kf5_includedir}/
%{_kf5_mkspecsdir}/qt_KWaylandClient.pri
%{_kf5_mkspecsdir}/qt_KWaylandServer.pri

%changelog
* Sat Apr 14 2018 lbeltrame@kde.org
- Update to 5.45.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.45.0.php
- Changes since 5.44.0:
  * Add Remote Access interface to KWayland
  * [server] Add support for the frame semantics of Pointer version 5 (kde#389189)
* Tue Mar 13 2018 lbeltrame@kde.org
- Update to 5.44.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.44.0.php
- Changes since 5.43.0:
  * Implement releasing of client-freed output
  * [server] Properly handle the situation when the DataSource for a drag gets destroyed (kde#389221)
  * [server] Don't crash when a subsurface gets commited whose parent surface got destroyed (kde#389231)
- Dropped patches, now upstream:
  * 0001-server-Don-t-crash-when-a-subsurface-gets-commited-w.patch
* Tue Feb 13 2018 lbeltrame@kde.org
- Update to 5.43.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.43.0.php
- Changes since 5.42.0:
  * Fix typo
* Tue Feb  6 2018 lbeltrame@kde.org
- Add 0001-server-Don-t-crash-when-a-subsurface-gets-commited-w.patch
  * Upstream fix to prevent kwin from crashing when opening
    systemsettings (kde#389231)
* Tue Jan 16 2018 lbeltrame@kde.org
- Update to 5.42.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.42.0.php
- Changes since 5.41.0:
  * Remove obsolete reviewboardrc file
  * Minor doxygen change to group new bind/create methods
  * Fix naming inconsistency
  * Resolve some merge issues
  * Unit test for Server Decoration Palette
  * Create interface for passing server decoration palettes
  * Explicitly include std::bind functions
  * [server] Add a method IdleInterface::simulateUserActivity
  * Fix regression caused by backward compatibility support in data source
  * Fix @since version tags
  * Add support for version 3 of data device manager interface (kde#386993)
  * Scope exported/imported objects to the test
  * Fix ASAN warning on TestXdgForeign
  * Replace QCOMPARE(nullptr) with QVERIFY
  * Fix error in WaylandSurface::testDisconnect
  * Explicit QCOMPARE(QString,QString)
  * Add explicit AppMenu protocol
  * Fix ASAN warnings in XDGForeignV2Interface
  * Fix exlude generated file from automoc feature
* Sun Dec 17 2017 lbeltrame@kde.org
- Update to 5.41.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.41.0.php
- Changes since 5.40.0:
  * Fix testWaylandFullscreenShell.
  * Expose wl_display_set_global_filter as a virtual method
  * Fix kwayland-testXdgShellV6.
  * Add support for zwp_idle_inhibit_manager_v1
  * [server] Support inhibiting the IdleInterface
* Mon Nov 13 2017 lbeltrame@kde.org
- Update to 5.40.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.40.0.php
- Changes since 5.39.0:
  * [client] Drop the checks for platformName being "wayland"
  * Don't duplicate connect to wl_display_flush
  * don't qcompare with nullptr
  * Wayland foreign protocol
  * Revert "Expose wl_display_set_global_filter as a virtual method"
  * Expose wl_display_set_global_filter as a virtual method
* Mon Oct 23 2017 lbeltrame@kde.org
- Update to 5.39.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.39.0.php
- Changes since 5.38.0:
  * Only send OutputConfig sendApplied / sendFailed to the right resource
  * Add missing command macro
  * Don't crash if a client (legally) uses deleted global contrast manager
  * Don't crash if a client (legally) uses a deleted global
  * Update @since docs
  * Missing licenses
  * Support XDG v6
* Tue Sep 12 2017 lbeltrame@kde.org
- Update to 5.38.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.38.0.php
- Changes since 5.37.0:
  * Treat input RGB buffers as premultiplied
  * Update SurfaceInterface outputs when an output global gets destroyed
  * KWayland::Client::Surface track output destruction
  * Do not leak symbols of pimpl classes, protect with Q_DECL_HIDDEN
  * Avoid sending data offers from an invalid source. (kde#383054)
* Sat Aug 12 2017 christophe@krop.fr
- Update to 5.37.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.37.0.php
- Changes since 5.36.0 :
  * Make unittest independent from the location of the executable.
  * autotests: prepare for CMAKE_RUNTIME_OUTPUT_DIRECTORY being set
  * Destroy all kwayland objects created by registry when it is destroyed
  * Emit connectionDied if the QPA is destroyed
  * [client] Track all created ConnectionThreads and add API to access them
  * [server] Send text input leave if focused surface gets unbound
  * [server] Send pointer leave if focused surface gets unbound
  * Drop unused variable
  * [client] Properly track enteredSurface in Keyboard
  * [server] Send keyboard leave when client destroys the focused surface (kde#382280)
  * check Buffer validity (kde#381953)
* Wed Jul 12 2017 lbeltrame@kde.org
- Update to 5.36.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.36.0.php
- Changes since 5.35.0:
  * [autotests/server] Check whether test is run as root
  * [FEATURE] Option to build & install QCH file with the public API dox
* Sun Jun 11 2017 lbeltrame@kde.org
- Update to 5.35.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.35.0.php
- Changes since 5.34.0:
  * Autotests: solve warning for QProcess::ProcessState metatype registration
  * Fix for TestQtSurfaceExtension in path with spaces
  * API dox: add some minimal docs to more class to have them covered by doxygen
  * API dox: add some minimal docs to class to have them covered by doxygen
  * API dox: Use doxygen notation to have comments used
  * API dox: fix @link usage
  * add requestToggleKeepAbove/below
  * Keep QIcon::fromTheme in main thread
  * Remove pid changedSignal in Client::PlasmaWindow
  * add pid to plasma window management protocol
* Mon May 15 2017 fabian@ritter-vogt.de
- Update to 5.34.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.34.0.php
- Changes since 5.33.0:
  * Validate surface is valid when sending TextInput leave event
  * Fix autotests on the FreeBSD CI.
* Sat Apr 15 2017 lbeltrame@kde.org
- Update to 5.33.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.33.0.php
- Changes since 5.32.0:
  * Upgrade ECM and KF5 version requirements for 5.33.0 release.
  * Add support for wl_shell_surface::set_popup and popup_done
  * Upgrade KF5 version to 5.33.0.
* Fri Apr  7 2017 alarrosa@suse.com
- Drop fix-wayland-1.3-dependency.diff which isn't needed anymore
  since SLE12 SP2.
* Sun Mar 19 2017 lbeltrame@kde.org
- Update to 5.32.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.32.0.php
- Changes since 5.31.0:
  * Upgrade ECM and KF5 version requirements for 5.32.0 release.
  * Upgrade KF5 version to 5.32.0.
* Thu Feb  9 2017 hrvoje.senjan@gmail.com
- Update to 5.31.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.31.0.php
* Mon Jan  9 2017 hrvoje.senjan@gmail.com
- Update to 5.30.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.30.0.php
* Sun Dec  4 2016 hrvoje.senjan@gmail.com
- Update to 5.29.0
  * [client] Fix nullptr dereference in ConfinedPointer
    and LockedPointer
  * [client] Install pointerconstraints.h
  * [server] Fix regression in
    SeatInterface::end/cancelPointerPinchGesture
  * Implementation of PointerConstraints protocol
  * [server] Reduce overhead of pointersForSurface
  * Return SurfaceInterface::size in global compositor space
  * [tools/generator] Generate enum FooInterfaceVersion on
    server side
  * [tools/generator] Wrap wl_fixed request args in
    wl_fixed_from_double
  * [tools/generator] Generate implementation of
    client side requests
  * [tools/generator] Generate client side resource factories
  * [tools/generator] Generate callbacks and listener
    on client side
  * [tools/generator] Pass this as q pointer to
    Client::Resource::Private
  * [tools/generator] Generate Private::setup(wl_foo *arg)
    on client side
  * Implementation of PointerGestures protocol
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.29.0.php
* Wed Nov 16 2016 hrvoje.senjan@gmail.com
- Rebase fix-wayland-1.3-dependency.diff
* Sun Nov  6 2016 hrvoje.senjan@gmail.com
- Update to 5.28.0
  * Improved relocatability of CMake export
  * [tools] Fix generation of wayland_pointer_p.h
  * [tools] Generate eventQueue methods only for global classes
  * [server] Fix crash on updating focused keyboard surface
  * [server] Fix possible crash on creation of DataDevice
  * [server] Ensure we have a DataSource on the DataDevice
    in setSelection
  * [tools/generator] Improve resource destruction on server side
  * Add request to have focus in a PlasmaShellSurface of Role Panel
  * Add auto-hiding panel support to PlasmaShellSurface interface
  * Support passing generic QIcon through PlasmaWindow interface
  * [server] Implement the generic window property
    in QtSurfaceExtension
  * [client] Add methods to get ShellSurface from a QWindow
  * [server] Send pointer events to all wl_pointer resources
    of a client
  * [server] Don't call wl_data_source_send_send if
    DataSource is unbound
  * [server] Use deleteLater when a ClientConnection gets destroyed
    (kde#370232)
  * Implement support for the relative pointer protocol
  * [server] Cancel previous selection from SeatInterface::setSelection
  * [server] Send key events to all wl_keyboard resources of a client
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.28.0.php
* Sun Oct  2 2016 hrvoje.senjan@gmail.com
- Update to 5.27.0
  * [server] Don't send key release for not pressed keys and
    no double key press (kde#366625)
  * [server] When replacing the clipboard selection previous
    DataSource needs to be cancelled (kde#368391)
  * Add support for Surface enter/leave events
  * [client] Track all created Outputs and add static get method
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.27.0.php
* Tue Sep  6 2016 hrvoje.senjan@gmail.com
- Update to 5.26.0
  * Make linux/input.h compile time optional
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.26.0.php
* Wed Aug 10 2016 alarrosa@suse.com
- Rebase fix-wayland-1.3-dependency.diff
* Sun Aug  7 2016 hrvoje.senjan@gmail.com
- Update to 5.25.0
  * Qt >= 5.5 is now required
  * [client] Use a QPointer for the enteredSurface in Pointer
  * Expose Geometry in PlasmaWindowModel
  * Add a geometry event to PlasmaWindow
  * [src/server] Verify that surface has a resource before sending pointer enter
  * Add support for xdg-shell
  * [server] Properly send a selection clear prior to keyboard focus enter
  * [server] Handle no XDG_RUNTIME_DIR situation more gracefully
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.25.0.php
* Wed Jul  6 2016 hrvoje.senjan@gmail.com
- Update to 5.24.0
  * Add a parent_window event to Plasma Window interface
  * Properly handle destroying a Pointer/Keyboard/Touch resource
  * [server] Delete dead code: KeyboardInterface::Private::sendKeymap
  * [server] Add support for setting the clipboard selection
    DataDeviceInterface manually
  * [server] Ensure that Resource::Private::get returns nullptr
    if passed a nullptr
  * [server] Add resource check in QtExtendedSurfaceInterface::close
  * [server] Unset SurfaceInterface pointer in referenced objects
    when being destroyed
  * [server] Fix error message in QtSurfaceExtension Interface
  * [server] Introduce a Resource::unbound signal emitted from
    unbind handler
  * [server] Don't assert when destroying a still
    referenced BufferInterface
  * Add destructor request to org_kde_kwin_shadow and
    org_kde_kwin_shadow_manager
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.24.0.php
* Mon Jun  6 2016 hrvoje.senjan@gmail.com
- Update to 5.23.0
  * [client] Don't check resource version for PlasmaWindow
  * Introduce an initial state event into Plasma Window protocol
  * [server] Trigger error if a transient request tries to parent
    to itself
  * [server] Properly handle the case that a PlasmaWindow is unmapped
    before client bound it
  * [server] Properly handle destructor in SlideInterface
  * Add support for touch events in fakeinput protocol and interface
  * [server] Standardize the destructor request handling for Resources
  * Implement wl_text_input and zwp_text_input_v2 interfaces
  * [server] Prevent double delete of callback resources
    in SurfaceInterface
  * [server] Add resource nullptr check to ShellSurfaceInterface
  * [server] Compare ClientConnection instead of wl_client
    in SeatInterface
  * [server] Improve the handling when clients disconnect
  * server/plasmawindowmanagement_interface.cpp - fix -Wreorder warning
  * [client] Add context pointer to connects in PlasmaWindowModel
  * Many fixes related to destruction
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.23.0.php
* Sat May  7 2016 hrvoje.senjan@gmail.com
- Update to 5.22.0 (boo#980066)
  * KWayland is now part of KDE Frameworks
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.22.0.php
* Tue Apr 19 2016 hrvoje.senjan@gmail.com
- Update to 5.6.3
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.6.3.php
* Tue Apr  5 2016 hrvoje.senjan@gmail.com
- Update to 5.6.2
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.6.2.php
* Tue Mar 29 2016 hrvoje.senjan@gmail.com
- Update to 5.6.1
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.6.1.php
* Sun Mar 20 2016 hrvoje.senjan@gmail.com
- Update to 5.6.0
  * New feature release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.6.0.php
* Tue Mar  1 2016 hrvoje.senjan@gmail.com
- Update to 5.5.5 (boo#968966)
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.5.5.php
* Wed Jan 27 2016 hrvoje.senjan@gmail.com
- Update to 5.5.4:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.5.4.php
* Wed Jan  6 2016 hrvoje.senjan@gmail.com
- Update to 5.5.3:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.5.3.php
* Wed Dec 23 2015 alarrosa@suse.com
- Add fix-wayland-1.3-dependency.diff again, rebased to apply correctly
  now that there are wayland packages for SLE12 updated with the new
  requirements from wayland 1.7
* Wed Dec 23 2015 hrvoje.senjan@gmail.com
- Update to 5.5.2:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.5.2.php
* Tue Dec 15 2015 hrvoje.senjan@gmail.com
- Update to 5.5.1:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.5.1.php
* Sat Dec 12 2015 hrvoje.senjan@gmail.com
- Update to 5.5.0:
  * For more details please see:
    https://dot.kde.org/2015/12/08/plasma-55-beautiful-new-artwork
- Move to cmake(...) BuildRequires where possible
- Drop no longer applicable fix-wayland-1.3-dependency.diff
* Sun Nov  8 2015 hrvoje.senjan@gmail.com
- Update to 5.4.3 (boo#955068):
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.4.3.php
* Thu Oct 29 2015 alarrosa@suse.com
- Added fix-wayland-1.3-dependency.diff -> changed requirements for
  SLE12, where an older wayland version has been patched to support
  the required features from wayland 1.3.0 needed by kwayland
* Sun Oct  4 2015 hrvoje.senjan@gmail.com
- Update to 5.4.2:
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.4.2.php
* Thu Sep 10 2015 hrvoje.senjan@gmail.com
- Update to 5.4.1:
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.4.1.php
* Mon Aug 24 2015 hrvoje.senjan@gmail.com
- Update to 5.4.0:
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.4.0.php
* Sun Aug 16 2015 hrvoje.senjan@gmail.com
- Update to 5.3.95 aka 5.4 beta:
  This release of Plasma brings many nice touches for our users
  such as much improved high DPI support, KRunner auto-completion
  and many new beautiful Breeze icons. It also lays the ground for
  the future with a tech preview of Wayland session available.
  We're shipping a few new components such as an Audio Volume
  Plasma Widget, monitor calibration tool and the User Manager
  tool comes out beta.
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.3.95.php
- Merge the two shlib packages into one main one
* Sun Jun 28 2015 hrvoje.senjan@gmail.com
- Update to 5.3.2:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.3.2.php
* Fri May 22 2015 hrvoje.senjan@gmail.com
- Update to 5.3.1:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.3.1.php
* Thu Apr 23 2015 hrvoje.senjan@gmail.com
- Update to 5.3 Final:
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.3.0.php
* Sat Apr 11 2015 hrvoje.senjan@gmail.com
- Update to 5.2.95 aka 5.3 beta:
  * New feature release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.2.95.php
- Update required Qt version to 5.4.0
- Added pkgconfig(egl) BuildRequires
* Thu Mar 19 2015 hrvoje.senjan@gmail.com
- Update to 5.2.2:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.2.2.php
* Fri Feb 20 2015 hrvoje.senjan@gmail.com
- Update to 5.2.1:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.2.1.php
* Mon Jan 26 2015 hrvoje.senjan@gmail.com
- Update to 5.2 Final:
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.2.0.php
* Tue Jan 13 2015 hrvoje.senjan@gmail.com
- Update to 5.2 Beta aka 5.1.95:
  * Undo changes to Plasma desktop layout
  * Smarter sorting of results in KRunner
  * Breeze window decoration theme adds a new look to your
    desktop and is now used by default
  * New white mouse cursor theme for Breeze.
  * New plasma widgets: 15 puzzle, web browser, show desktop
  * Over 300 bugs fixed throughout Plasma modules.
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.1.95.php
- Drop 0001-Do-not-find-unused-Wayland-components.patch, upstreamed
- Build the server shlib
* Thu Dec 11 2014 hrvoje.senjan@gmail.com
- Update to 5.1.2:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.1.2.php
* Thu Nov  6 2014 hrvoje.senjan@gmail.com
- Update to 5.1.1:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.1.1.php
* Mon Nov  3 2014 hrvoje.senjan@gmail.com
- Added 0001-Do-not-find-unused-Wayland-components.patch to drop
  not needed BuildRequires, pkgconfig(wayland-egl)
* Thu Oct  9 2014 hrvoje.senjan@gmail.com
- Update to 5.1 Final:
  * Bugfixes since RC1
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.1.0.php
* Fri Sep 26 2014 hrvoje.senjan@gmail.com
- Update to 5.0.95:
  * Minor API improvements since last update
* Tue Sep 23 2014 hrvoje.senjan@gmail.com
- Activate KWayland package - KDE bindings for Wayland protocol and
  library
